@@ -1,6 +1,6 @@
 check.RS <- function(io){
   # Preliminaries
-  if(class(io) != "InputOutput") stop('io should be of "InputOutput" class. See ?as.inputoutput')
+  if(!"InputOutput" %in% class(io)) stop('io should be of "InputOutput" class. See ?as.inputoutput')
   RS_label <- io$RS_label
   regions <- unique(RS_label[, 1])
   RS.1 <- RS_label[RS_label[, 1] == regions[1],]
